

# moziai

moziai是在墨子推演平台上运行强化学习的python组件，目的是方便大家在墨子平台开发强化学习算法，墨子平台提供了与强化学习的python代码进行交互的界面，以获取状态空间并执行动作。用户可以基于墨子AI开发包开展深度学习、机器学习、对抗博弈、多智能体、行为树等多种模式的人工智能研究，以期在战术战法研究、效能评估、智能蓝军、规则学习与策略更新等多个应用领域产生突破性成果。

## 快速入门指南

### 获取moziai

获取moziai软件包最简单的方法是从gitee克隆到本地：

>git clone [https://gitee.com/hs-defense/moziai.git](https://gitee.com/hs-defense/moziai.git)
python代码的运行版本为python3.6.5。

### 获取墨子推演平台

获取墨子推演平台，可以到华戍防务技术有限公司下载中心进行下载, 其中包括了windows版本和linux版本。

>[http://www.hs-defense.com/#/mz/download](https://gitee.com/link?target=http%3A%2F%2Fwww.hs-defense.com%2F%23%2Fmz%2Fdownload)
python的版本为python3.6.5。 硬件环境我们建议：CPU i5及以上，显卡GTX 960 及以上（兼容cuda8.0以上的显卡驱动），内存8G。

### moziai运行测试

克隆代码后，进入到demo案例文件夹， moziai/mozi_ai_sdk/examples/uav_anti_tank， 运行main.py文件。在墨子推演平台能够可视化的看到代码运行的效果。 具体的环境细节以及安装步骤，请阅读 “墨子AI开发环境”安装手册。

